"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.registerUpdateHook = exports.registerTransactionHook = void 0;
const updateCallbacks = {};
const transactionCallbacks = {};

/**
 * Entry point for update callbacks. This is triggered from C++ with params.
 */
global.triggerUpdateHook = function (dbName, table, opType, rowId) {
  const callback = updateCallbacks[dbName];
  if (!callback) {
    return;
  }
  callback({
    opType,
    table,
    rowId
  });
  return null;
};
const registerUpdateHook = (dbName, callback) => {
  updateCallbacks[dbName] = callback;
};

/**
 * Entry point for transaction callbacks. This is triggered from C++ with params.
 */
exports.registerUpdateHook = registerUpdateHook;
global.triggerTransactionFinalizerHook = function (dbName, eventType) {
  const callback = transactionCallbacks[dbName];
  if (!callback) {
    return;
  }
  callback(eventType);
  return null;
};
const registerTransactionHook = (dbName, callback) => {
  transactionCallbacks[dbName] = callback;
};
exports.registerTransactionHook = registerTransactionHook;
//# sourceMappingURL=table-updates.js.map